==> haskell-microlens-platform-0.3.11-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-platform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-platform
version: 0.3.11
id: microlens-platform-0.3.11-6Jy3TjWUKPGtXYdYTjkJL
key: microlens-platform-0.3.11-6Jy3TjWUKPGtXYdYTjkJL
license: BSD-3-Clause
maintainer: Monadfix <hi@monadfix.io>
author: Edward Kmett, Artyom Kazak
homepage: http://github.com/monadfix/microlens
synopsis: Feature-complete microlens
description:
    This package exports a module which is the recommended starting point for using <http://hackage.haskell.org/package/microlens microlens> if you aren'\''t trying to keep your dependencies minimal. By importing @Lens.Micro.Platform@ you get all functions and instances from <http://hackage.haskell.org/package/microlens microlens>, <http://hackage.haskell.org/package/microlens-th microlens-th>, <http://hackage.haskell.org/package/microlens-mtl microlens-mtl>, <http://hackage.haskell.org/package/microlens-ghc microlens-ghc>, as well as instances for @Vector@, @Text@, and @HashMap@.
    .
    The minor and major versions of microlens-platform are incremented whenever the minor and major versions of any other microlens package are incremented, so you can depend on the exact version of microlens-platform without specifying the version of microlens (microlens-mtl, etc) you need.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.
category: Data, Lenses
abi: 2687ed2dad46df12d3f8368762b91753
exposed: True
exposed-modules:
    Lens.Micro.Platform Lens.Micro.Platform.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-platform-0.3.11
library-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-platform-0.3.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/microlens-platform-0.3.11
hs-libraries: HSmicrolens-platform-0.3.11-6Jy3TjWUKPGtXYdYTjkJL
depends:
    base-4.12.0.0 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    microlens-0.4.10-LVgmazyXGvNKvoQElrYSfS
    microlens-ghc-0.4.10-3WPL63hZTzx5JfoSe4avt0
    microlens-mtl-0.1.11.1-CE5sGqQZkL9EXFDjpbpByt
    microlens-th-0.4.2.3-2ty2TK3jSO111y1tN2Ao3p text-1.2.3.1
    unordered-containers-0.2.10.0-2N7l4ZvxBr3HGayD0s0P1Q
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-microlens-platform/html/microlens-platform.haddock
haddock-html: /usr/share/doc/haskell-microlens-platform/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-platform-0.4.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microlens-platform.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microlens-platform
version: 0.4.0
id: microlens-platform-0.4.0-ZyMWxEzL09JA6MSSLDktz
key: microlens-platform-0.4.0-ZyMWxEzL09JA6MSSLDktz
license: BSD-3-Clause
maintainer: Monadfix <hi@monadfix.io>
author: Edward Kmett, Artyom Kazak
homepage: http://github.com/monadfix/microlens
synopsis: microlens + all batteries included (best for apps)
description:
    This package exports a module which is the recommended starting point for using <http://hackage.haskell.org/package/microlens microlens> if you aren'\''t trying to keep your dependencies minimal. By importing @Lens.Micro.Platform@ you get all functions and instances from <http://hackage.haskell.org/package/microlens microlens>, <http://hackage.haskell.org/package/microlens-th microlens-th>, <http://hackage.haskell.org/package/microlens-mtl microlens-mtl>, <http://hackage.haskell.org/package/microlens-ghc microlens-ghc>, as well as instances for @Vector@, @Text@, and @HashMap@.
    .
    The minor and major versions of microlens-platform are incremented whenever the minor and major versions of any other microlens package are incremented, so you can depend on the exact version of microlens-platform without specifying the version of microlens (microlens-mtl, etc) you need.
    .
    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.
category: Data, Lenses
abi: 97d9b08a03be9aab04317355759e474e
exposed: True
exposed-modules:
    Lens.Micro.Platform Lens.Micro.Platform.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-platform-0.4.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/microlens-platform-0.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/microlens-platform-0.4.0
hs-libraries: HSmicrolens-platform-0.4.0-ZyMWxEzL09JA6MSSLDktz
depends:
    base-4.12.0.0 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    microlens-0.4.11.1-5dh821ORebgAorhvJor7TN
    microlens-ghc-0.4.11.1-B9uxXF1aXHWLQD0xUH9ve5
    microlens-mtl-0.2.0.1-E4YQOt1SovZ6XqAZ7j7hTE
    microlens-th-0.4.3.1-AUW9LaqhPnN9WhzH0kkXqs text-1.2.3.1
    unordered-containers-0.2.10.0-8dby3miKFglJ7BLkdgbDGw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-microlens-platform/html/microlens-platform.haddock
haddock-html: /usr/share/doc/haskell-microlens-platform/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
